from .core import VoiceAssistant, speak, listen
from .exceptions import (
    VoiceLibError,
    ListenTimeoutError,
    AudioCaptureError,
    SpeechError,
    InitializationError
)

__all__ = [
    'VoiceAssistant',
    'speak',
    'listen',
    'VoiceLibError',
    'ListenTimeoutError',
    'AudioCaptureError',
    'SpeechError',
    'InitializationError'
]

__version__ = '0.1.0'